@@ -23,16 +23,16 @@ from aliyunsdkvideoseg.endpoint import endpoint_data
 class GetAsyncJobResultRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'videoseg', '2020-03-20', 'GetAsyncJobResult','videoseg')
+		RpcRequest.__init__(self, 'videoseg', '2020-03-20', 'GetAsyncJobResult')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_JobId(self):
+	def get_JobId(self): # String
 		return self.get_body_params().get('JobId')
 
-	def set_JobId(self,JobId):
-		self.add_body_params('JobId', JobId)
\ No newline at end of file
+	def set_JobId(self, JobId):  # String
+		self.add_body_params('JobId', JobId)
