@@ -23,16 +23,16 @@ from aliyunsdkvideoseg.endpoint import endpoint_data
 class SegmentGreenScreenVideoRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'videoseg', '2020-03-20', 'SegmentGreenScreenVideo','videoseg')
+		RpcRequest.__init__(self, 'videoseg', '2020-03-20', 'SegmentGreenScreenVideo')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_VideoURL(self):
+	def get_VideoURL(self): # String
 		return self.get_body_params().get('VideoURL')
 
-	def set_VideoURL(self,VideoURL):
-		self.add_body_params('VideoURL', VideoURL)
\ No newline at end of file
+	def set_VideoURL(self, VideoURL):  # String
+		self.add_body_params('VideoURL', VideoURL)
