@@ -23,16 +23,16 @@ from aliyunsdkvideoseg.endpoint import endpoint_data
 class SegmentHalfBodyRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'videoseg', '2020-03-20', 'SegmentHalfBody','videoseg')
+		RpcRequest.__init__(self, 'videoseg', '2020-03-20', 'SegmentHalfBody')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_VideoUrl(self):
+	def get_VideoUrl(self): # String
 		return self.get_body_params().get('VideoUrl')
 
-	def set_VideoUrl(self,VideoUrl):
-		self.add_body_params('VideoUrl', VideoUrl)
\ No newline at end of file
+	def set_VideoUrl(self, VideoUrl):  # String
+		self.add_body_params('VideoUrl', VideoUrl)
